import type { CacheRequestConfig } from '../cache/axios';
import type { MaybePromise } from '../util/types';
import type { AxiosStorage, CachedStorageValue, StorageValue } from './types';
/** Returns true if the provided object was created from {@link buildStorage} function. */
export declare const isStorage: (obj: unknown) => obj is AxiosStorage;
/** Returns true if this storage is expired, but it has sufficient properties to stale. */
export declare function canStale(value: CachedStorageValue): boolean;
/** Checks if the provided cache is expired. You should also check if the cache {@link canStale} */
export declare function isExpired(value: CachedStorageValue): boolean;
export declare type BuildStorage = Omit<AxiosStorage, 'get'> & {
    /**
     * Returns the value for the given key. This method does not have to make checks for
     * cache invalidation or anything. It just returns what was previous saved, if present.
     *
     * @param key The key to look for
     * @param currentRequest The current {@link CacheRequestConfig}, if any
     */
    find: (key: string, currentRequest?: CacheRequestConfig) => MaybePromise<StorageValue | undefined>;
};
/**
 * Builds a custom storage.
 *
 * **Note**: You can only create an custom storage with this function.
 *
 * @example
 *
 * ```js
 * const myStorage = buildStorage({
 *   find: () => {...},
 *   set: () => {...},
 *   remove: () => {...}
 * });
 *
 * const axios = setupCache(axios, { storage: myStorage });
 * ```
 */
export declare function buildStorage({ set, find, remove }: BuildStorage): AxiosStorage;
//# sourceMappingURL=build.d.ts.map