import type { AxiosStorage, StorageValue } from './types';
/**
 * Creates a simple in-memory storage. This means that if you need to persist data between
 * page or server reloads, this will not help.
 *
 * This is the storage used by default.
 *
 * If you need to modify it's data, you can do by the `data` property.
 *
 * @example
 *
 * ```js
 * const memoryStorage = buildMemoryStorage();
 *
 * setupCache(axios, { storage: memoryStorage });
 *
 * // Simple example to force delete the request cache
 *
 * const { id } = axios.get('url');
 *
 * delete memoryStorage.data[id];
 * ```
 *
 * @param {boolean} cloneData If the data returned by `find()` should be cloned to avoid
 *   mutating the original data outside the `set()` method.
 */
export declare function buildMemoryStorage(cloneData?: boolean): MemoryStorage;
export declare type MemoryStorage = AxiosStorage & {
    data: Record<string, StorageValue>;
};
//# sourceMappingURL=memory.d.ts.map